import axios from 'axios';
import { ListParams, queryList } from '@/api/list';
import qs from "query-string";

export interface DeptCreateRecord {
  name: string;
  code: number;
  remark: string;
}
export interface DeptRecord extends DeptCreateRecord {
  id: number;
}

export function create(data: DeptCreateRecord) {
  return axios.post(`/api/dept`, data);
}

export function update(data: DeptRecord) {
  return axios.patch(`/api/dept/${data.id}`, data);
}


export function getDetail(id: number) {
  return axios.get<DeptRecord>(`/api/dept/${id}`);
}

export function remove(id: number) {
  return axios.delete(`/api/dept/${id}`);
}

export function listDepts(params?: ListParams<Partial<DeptRecord>>) {
  return axios.get<DeptRecord[]>(`/api/dept`, {
    params,
    paramsSerializer: (obj) => {
      return qs.stringify(obj);
    },
  });
}

export function queryDepts(params?: ListParams<Partial<DeptRecord>>) {
  return queryList(`/api/dept`, params);
}
