import axios from 'axios';
import type { RouteRecordNormalized } from 'vue-router';
import { UserState } from '@/store/modules/user/types';
import qs from 'query-string';
import { RoleRecord } from '@/api/role';
import { DeptRecord } from '@/api/dept';

export interface Res {
  code: number;
  data: object;
  msg: string;
}

export interface LoginData {
  username: string;
  password: string;
}

export interface LoginRes {
  token: string;
}

export interface PasswordReSetModel {
  newPassword: string;
  confirmPassword: string;
}

export interface CreateRecord {
  username: string;
  name: string;
  phone: string;
  email: string;
  enableState: string;
  dept: DeptRecord | undefined;
  roles: RoleRecord[];
}
export interface SelfRecord {
  username: string;
  name: string;
  phone: string;
  email: string;
  remark: string;
}

export interface UserRecord extends CreateRecord {
  id: number;
}

export interface UserParams extends Partial<UserRecord> {
  current: number;
  pageSize: number;
}

export interface Pageable {
  pageNumber: number;
  pageSize: number;
  sort: {
    sorted: boolean;
    unsorted: boolean;
    empty: boolean;
  };
  offset: number;
  unpaged: boolean;
  paged: boolean;
}

export interface UserListRes {
  content: UserRecord[];
  totalPages: number;
  totalElements: number;
  size: number;
  number: number;
  pageable: Pageable;
}

export function login(data: LoginData) {
  return axios.post<LoginRes>('/api/user/login', data);
}

export function logout() {
  return axios.post<LoginRes>('/api/user/logout');
}

export function resetPassword(data: PasswordReSetModel) {
  return axios.patch('/api/user/self/update-password', data);
}

export function create(data: CreateRecord) {
  return axios.post(`/api/user`, data);
}

export function update(data: UserRecord) {
  return axios.patch<Res>(`/api/user/${data.id}`, data);
}

export function selfUpdate(data: UserState) {
  return axios.patch<Res>(`/api/user/self`, data);
}

export function getUserInfo() {
  return axios.get<UserState>('/api/user/info');
}

export function getUserDetail(id: number) {
  return axios.get<UserState>(`/api/user/${id}`);
}

export function remove(id: number) {
  return axios.delete(`/api/user/${id}`);
}

export function getMenuList() {
  return axios.post<RouteRecordNormalized[]>('/api/user/menu');
}

export function queryUserList(params: UserParams) {
  return axios.get<UserListRes>('/api/user', {
    params,
    paramsSerializer: (obj) => {
      return qs.stringify(obj);
    },
  });
}
